@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -33,9 +33,9 @@ public:
     ~CustomDebugSettingsPage();
 
     void fillList(const LoggingCategory::List &list);
-    LoggingCategory::List rules();
+    LoggingCategory::List rules() const;
 private:
-    void slotRemoveRule();
+    void slotRemoveRules();
     void slotAddRule();
     void slotEditRule();
     void updateButtons();
