@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -21,23 +21,22 @@
 #ifndef ENVIRONMENTPLAINTEXTEDIT_H
 #define ENVIRONMENTPLAINTEXTEDIT_H
 
-#include <QPlainTextEdit>
+#include <QTextEdit>
 class QPaintEvent;
-class EnvironmentPlainTextEdit : public QPlainTextEdit
+class EnvironmentPlainTextEdit : public QTextEdit
 {
     Q_OBJECT
 public:
-    explicit EnvironmentPlainTextEdit(QWidget *parent = Q_NULLPTR);
+    explicit EnvironmentPlainTextEdit(QWidget *parent = nullptr);
     ~EnvironmentPlainTextEdit();
 
 protected:
-    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *event) override;
 
-    void contextMenuEvent(QContextMenuEvent *event) Q_DECL_OVERRIDE;
-private Q_SLOTS:
+    void contextMenuEvent(QContextMenuEvent *event) override;
+private:
     void slotGeneralPaletteChanged();
 
-private:
     QColor mTextColor;
 };
 
