@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -31,10 +31,13 @@ class KDEApplicationDebugSettingPage : public QWidget
     Q_OBJECT
 public:
     explicit KDEApplicationDebugSettingPage(QWidget *parent = nullptr);
-    ~KDEApplicationDebugSettingPage();
+    ~KDEApplicationDebugSettingPage() override;
     void fillList(const LoggingCategory::List &list);
-    LoggingCategory::List rules() const;
+    LoggingCategory::List rules(bool forceSavingAllRules) const;
     void insertCategories(const LoggingCategory::List &list);
+
+    void restoreToDefault();
+
 protected:
     bool eventFilter(QObject *obj, QEvent *event) override;
 
